@@ -20,7 +20,7 @@
  *
  *
  * nessus-fetch is a simple utility to retrieve Nessus plugins from nessus.org
- * $Id: nessus-fetch.c,v 1.1.2.13 2005/07/21 16:34:01 renaud Exp $
+ * $Id: nessus-fetch.c,v 1.1.2.18 2005/11/04 11:33:38 renaud Exp $
  */
 #include <includes.h>
 
@@ -38,6 +38,8 @@
 #define SUCCESS_MSG  "@SUCCESS@"
 #define CONFIG_FILE "nessus-fetch.rc"
 
+#define SEGSIZE 1024
+
 #ifndef INADDR_NONE
 #define INADDR_NONE 0xffffffff
 #endif
@@ -76,6 +78,58 @@ static int block_socket(int soc)
   return 0;
 }
 
+int http_recv_headers(int soc, char ** result, int * len)
+{
+ char tmp[2048];
+ int sz = 4096;
+ int n;
+ char * buf;
+ int lines = 0;
+ int num = 0;
+ 
+ *result = NULL;
+ *len = 0;
+ 
+ buf = emalloc(sz);
+ tmp[ sizeof(tmp) - 1 ] = '\0';
+
+  for(;;)
+  {
+   n = recv_line(soc, tmp, sizeof(tmp) - 1);
+   lines ++;
+   if( n <= 0 )break;
+   
+   if(!strcmp(tmp, "\r\n")||
+      !strcmp(tmp, "\n"))break;
+   else 
+   {
+     num  += n;
+     if(num < sz)
+      strcat(buf, tmp);
+     else
+     {
+      if(sz > 1024 * 1024)
+       break;
+      else
+       sz = (sz * 2) > ( num + 1 ) ? (sz * 2) : (num + 1);
+	
+      buf = erealloc(buf, sz);
+      strcat(buf, tmp);
+      if(lines > 100)break;
+     }
+  }
+ }
+ 
+ if(num == 0)
+ {
+  efree(&buf);
+ }
+ 
+ *result = buf;
+ *len = num;
+ return 0;
+}
+
 
 
 /*-------------------------------------------------------------------------
@@ -367,7 +421,9 @@ static int recv_chunked_encoding(int fd, char * headers, int hlen, char ** buf,
   n = 0;
   do {
   int e = 0;
-  e = read_stream_connection_min(fd, mybuf + sz + n, total_len + 2 - n, total_len + 2 - n );
+  int l;
+  l = total_len + 2 - n > SEGSIZE ? SEGSIZE : total_len + 2 - n;
+  e = read_stream_connection_min(fd, mybuf + sz + n, 1, l );
   if ( e <= 0 ) break;
   n += e;
   } while ( n != total_len + 2);
@@ -426,8 +482,8 @@ static char * http_recv(int fd, int * totlen, int * headerslen, int * error_code
    int e;
    int readsz;
 
-   readsz = (len - n)  > 65535 ? 65535 : (len - n);
-   e = read_stream_connection_min(fd, retbuf + headers_len + n, readsz, readsz);
+   readsz = (len - n)  > SEGSIZE ? SEGSIZE : (len - n);
+   e = read_stream_connection_min(fd, retbuf + headers_len + n, 1, readsz);
    if ( e <= 0 ) break;
    else n += e;
   }
@@ -449,9 +505,8 @@ static char * http_recv(int fd, int * totlen, int * headerslen, int * error_code
   }
   else
   {
-#define CHUNKSZ 16384
    int len = headers_len;
-   int bufsz = len + CHUNKSZ * 5;
+   int bufsz = len + SEGSIZE * 5;
    char * buf = emalloc( bufsz );
    int n;
    
@@ -459,11 +514,11 @@ static char * http_recv(int fd, int * totlen, int * headerslen, int * error_code
    for (n = 0;; )
    {
    int e;
-   e = read_stream_connection(fd, buf + headers_len + n, CHUNKSZ);
+   e = read_stream_connection_min(fd, buf + headers_len + n, 1, SEGSIZE );
    if ( e <= 0 ) break;
    else { len += e; n += e; }
 
-   if ( len + CHUNKSZ >= bufsz )
+   if ( len + SEGSIZE >= bufsz )
 	{
 	 if ( bufsz > MAX_SIZE ) break;
 	 bufsz *= 2;
@@ -655,7 +710,7 @@ static int do_register( char * serial, int argc, char ** argv )
   fprintf(stderr, "could not connect to %s - %s\n", plug_get_hostname(hostinfo), strerror(errno));
   exit(1);
  } 
- stream_set_buffer(soc, 65535);
+ stream_set_buffer(soc, 0);
 
  write_stream_connection(soc, req, strlen(req));
    
