@@ -415,7 +415,13 @@ backend_convert(be)
   	buffer = estrdup("INFO");
   else if(!strcmp(t, "Security Hole"))
   	buffer = estrdup("REPORT");
+  else buffer = NULL;
  
+  if ( buffer == NULL )
+	{
+	 fprintf(stderr, "Error - line %d is malformed\n", line);
+	 continue;
+	}
   content = arg_get_value(port, buffer);
   
   if(!content)
