@@ -569,9 +569,10 @@ comm_get_preferences(prefs)
 
 
 static int
-cli_send_prefs_arglist(pref, upload)
+cli_send_prefs_arglist(pref, upload, pprefs)
  struct arglist * pref;
  harglst** upload;
+ int pprefs;
 {
  if(!pref)
   return -1;
@@ -586,7 +587,16 @@ cli_send_prefs_arglist(pref, upload)
      	harg_add_int(*upload, pref->value, 1);
    	}
 	
-    	network_printf("%s <|> %s\n", pref->name, pref->value);
+ 	if ( pprefs == 0 )	network_printf("%s <|> %s\n", pref->name, pref->value);
+	else if ( strchr(pref->value, ';') != NULL )
+	{
+	 char * p;
+	 p = strchr(pref->value, ';');
+	 p[0] = '\0';
+	 network_printf("%s <|> %s\n", pref->name, pref->value);
+	 p[0] = ';';
+	}
+        else network_printf("%s <|> %s\n", pref->name, pref->value);
     }
    else if(pref->type == ARG_INT)
     {
@@ -616,8 +626,8 @@ cli_comm_send_preferences(preferences)
  network_printf("ntp_short_status <|> yes\n");
  network_printf("ntp_client_accepts_notes <|> yes\n");
  network_printf("ntp_escape_crlf <|> yes\n");
- if(pref)cli_send_prefs_arglist(pref, &files_to_send);
- if(pprefs)cli_send_prefs_arglist(pprefs, &files_to_send);
+ if(pref)cli_send_prefs_arglist(pref, &files_to_send, 0);
+ if(pprefs)cli_send_prefs_arglist(pprefs, &files_to_send, 1);
  network_printf("<|> CLIENT\n");
  if(files_to_send)
  { 
@@ -950,9 +960,7 @@ comm_get_plugins()
            else
              arg_set_value(Scanners,  arg_get_value(plugin, "NAME"), -1, plugin); 
             if(scanner_set && 
-              ((int)arg_get_type(scanner_set, plugin_asc_id(plugin))<0))
-              arg_add_value(scanner_set, plugin_asc_id(plugin), ARG_INT,
-                 sizeof(int),(void*)1);
+              ((int)arg_get_type(scanner_set, plugin_asc_id(plugin))<0)) arg_add_value(scanner_set, plugin_asc_id(plugin), ARG_INT, sizeof(int),arg_get_value(plugin, "ENABLED"));
            }
           else
           {
@@ -966,8 +974,7 @@ comm_get_plugins()
               
            if(plugin_set &&
              ((int)arg_get_type(plugin_set, plugin_asc_id(plugin))<0))
-              arg_add_value(plugin_set, plugin_asc_id(plugin), ARG_INT,
-              sizeof(int),(void*)1);
+              arg_add_value(plugin_set, plugin_asc_id(plugin), ARG_INT, sizeof(int),arg_get_value(plugin, "ENABLED"));
             
            }
 	}
