@@ -540,13 +540,16 @@ attack_network(globals)
   int  save_session= 0;  
   int continuous   = 0;
   int detached     = 0;
-  hargwalk *  hw;
-  harglst * files;
-  char * key;
   int return_code = 0;
   char * port_range;
   plugins_scheduler_t sched;
   int fork_retries = 0;
+  harglst * files;
+  hargwalk * hw;
+  char * key;
+  struct timeval then, now;
+
+  gettimeofday(&then, NULL);
 
   host_ip.s_addr = 0;
   preferences    = arg_get_value(globals, "preferences");
@@ -902,6 +905,10 @@ stop:
   	goto start_attack_network;
 	}
   else if(detached)detached_end_session(globals);	
+
+
+  gettimeofday(&now, NULL);
+  log_write("Total time to scan all hosts : %ld seconds\n", now.tv_sec - then.tv_sec);
   
   return return_code;
 }
