@@ -18,7 +18,7 @@
  * This very simply utility generates/checks a signature for a given file
  *
  *
- * $Id: nessus-check-signature.c,v 1.1.2.1 2005/03/16 18:50:43 renaud Exp $
+ * $Id: nessus-check-signature.c,v 1.1.2.2 2005/07/07 00:19:39 renaud Exp $
  */
 #include <includes.h>
 #ifdef HAVE_SSL
@@ -38,9 +38,9 @@ int generate_signature(char * filename)
  RSA * rsa = NULL;
  FILE * fp = fopen(NESSUSD_STATEDIR "/nessus_org.priv.pem", "r");
  unsigned char  * result;
- int len;
+ unsigned int len;
  int i;
- char md[SHA_DIGEST_LENGTH+1];
+ unsigned char md[SHA_DIGEST_LENGTH+1];
  int be_len;
 
  SHA_CTX ctx;
