@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: nessusd.c,v 1.236.2.2 2005/03/21 22:55:19 renaud Exp $
+ * $Id: nessusd.c,v 1.236.2.5 2005/07/05 18:20:55 renaud Exp $
  */
 
 #include <includes.h>
@@ -251,7 +251,6 @@ start_daemon_mode
     setvbuf(stdout, NULL, _IOLBF, 0);
     setvbuf(stderr, NULL, _IOLBF, 0);
 #endif
-    log_write ("Redirecting debugging output to %s\n", s);  
 }
 
 
@@ -967,7 +966,7 @@ init_nessusd (options, first_pass, stop_early, be_quiet)
      int stop_early; /* 1: do some initialization, 2: no initialization */
      int be_quiet;
 {
-  int  isck;
+  int  isck = -1;
   struct arglist * plugins = NULL;
   struct arglist * preferences = NULL;
   struct nessus_rules * rules = NULL;
