@@ -74,7 +74,7 @@ int preferences_new(char * name)
  fprintf(fd, "be_nice = no\n\n");
 
 
- fprintf(fd, "# Log file (or 'syslog') : \n");
+ fprintf(fd, "# Log file : \n");
  fprintf(fd, "logfile = %s\n\n", NESSUSD_MESSAGES);
  fprintf(fd, "# Shall we log every details of the attack ?\n");
  fprintf(fd, "log_whole_attack = yes\n\n");
